import React, { useState } from 'react';
import RecordButton from './RecordButton';
import EditTypeSelector from './EditTypeSelector';
import './EditPanel.css';

function EditPanel({ selectedSection, onEdit, onUndo, onRedo }) {
  const [editType, setEditType] = useState('agentx');
  const [isTranscribing, setIsTranscribing] = useState(false);

  const handleTranscriptionComplete = async (transcribedText) => {
    setIsTranscribing(true);
    try {
      await onEdit(selectedSection, transcribedText, editType);
    } catch (error) {
      console.error('Error processing edit:', error);
    } finally {
      setIsTranscribing(false);
    }
  };

  return (
    <div className="edit-panel">
      {selectedSection ? (
        <>
          <h3 className="selected-section-label">
            Selected Section: {selectedSection.substring(0, 50)}...
          </h3>
          
          <EditTypeSelector 
            selectedType={editType}
            onTypeSelect={setEditType}
          />
          
          <div className="record-section">
            <RecordButton 
              onTranscriptionComplete={handleTranscriptionComplete}
              disabled={isTranscribing}
            />
            {isTranscribing && (
              <div className="transcribing-indicator">
                Processing your changes...
              </div>
            )}
          </div>

          <div className="history-buttons">
            <button onClick={onUndo} className="history-button">
              Undo
            </button>
            <button onClick={onRedo} className="history-button">
              Redo
            </button>
          </div>
        </>
      ) : (
        <div className="no-selection">
          Click any section in the preview to start editing
        </div>
      )}
    </div>
  );
}

export default EditPanel;

