import React, { useRef, useEffect } from 'react';
import './HTMLPreview.css';
import cursorIcon from '../assets/cursor.png';

function HTMLPreview({ html, onSectionSelect }) {
  const iframeRef = useRef(null);
  const scrollPositionRef = useRef({ top: 0, left: 0 });

  useEffect(() => {
    if (iframeRef.current) {
      const iframe = iframeRef.current;
      const doc = iframe.contentDocument || iframe.contentWindow.document;
      
      // Save current scroll position
      if (iframe.contentWindow) {
        scrollPositionRef.current = {
          top: iframe.contentWindow.scrollY,
          left: iframe.contentWindow.scrollX
        };
      }

      // Write HTML content
      doc.open();
      doc.write(html);
      doc.close();

      // Add click listener to sections
      const sections = doc.getElementsByTagName('section');
      Array.from(sections).forEach((section, index) => {
        section.addEventListener('click', (e) => {
          e.preventDefault();
          // Remove any existing cursors
          const cursors = doc.getElementsByClassName('cursor-indicator');
          Array.from(cursors).forEach(cursor => cursor.remove());
          
          // Add cursor at click position
          const cursor = doc.createElement('img');
          cursor.src = cursorIcon;
          cursor.className = 'cursor-indicator';
          cursor.style.position = 'absolute';
          cursor.style.left = `${e.pageX}px`;
          cursor.style.top = `${e.pageY}px`;
          cursor.style.width = '20px';
          cursor.style.height = '20px';
          cursor.style.zIndex = '9999';
          doc.body.appendChild(cursor);

          // Get section content and trigger callback
          const sectionContent = section.outerHTML;
          onSectionSelect(sectionContent, index);
        });
      });

      // Restore scroll position
      if (iframe.contentWindow) {
        iframe.contentWindow.scrollTo(
          scrollPositionRef.current.left,
          scrollPositionRef.current.top
        );
      }
    }
  }, [html, onSectionSelect]);

  return (
    <div className="html-preview">
      <iframe 
        ref={iframeRef}
        title="HTML Preview"
        className="preview-iframe"
      />
    </div>
  );
}

export default HTMLPreview;

