import React, { useState, useRef } from 'react';
import RecordRTC from 'recordrtc';
import { transcribeAudio } from '../services/whisperApi';
import './RecordButton.css';

function RecordButton({ onTranscriptionComplete, disabled }) {
  const [isRecording, setIsRecording] = useState(false);
  const [error, setError] = useState('');
  const mediaRecorderRef = useRef(null);

  const startRecording = async () => {
    try {
      const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
      mediaRecorderRef.current = RecordRTC(stream, {
        type: 'audio',
        mimeType: 'audio/webm',
        recorderType: RecordRTC.StereoAudioRecorder,
        numberOfAudioChannels: 1,
      });
      
      mediaRecorderRef.current.startRecording();
      setIsRecording(true);
      setError('');
    } catch (err) {
      setError('Microphone access error: ' + err.message);
      console.error('Recording error:', err);
    }
  };

  const stopRecording = () => {
    if (mediaRecorderRef.current) {
      mediaRecorderRef.current.stopRecording(async () => {
        const blob = mediaRecorderRef.current.getBlob();
        try {
          const transcribedText = await transcribeAudio(blob);
          onTranscriptionComplete(transcribedText);
        } catch (err) {
          setError('Transcription error: ' + err.message);
          console.error('Transcription error:', err);
        }
        setIsRecording(false);
      });
    }
  };

  const toggleRecording = () => {
    if (!isRecording) {
      startRecording();
    } else {
      stopRecording();
    }
  };

  return (
    <div className="record-button-container">
      <button
        className={`record-button ${isRecording ? 'recording' : ''}`}
        onClick={toggleRecording}
        disabled={disabled}
      >
        {isRecording ? 'Stop Recording' : 'Start Recording'}
      </button>
      {error && <div className="record-error">{error}</div>}
    </div>
  );
}

export default RecordButton;

