import React from 'react';
import { useNavigate } from 'react-router-dom';
import './SessionFooter.css';

function SessionFooter({ sessionId, lastSaved, onSave }) {
  const navigate = useNavigate();

  const handleSaveAndLeave = async () => {
    try {
      // First save current state
      await onSave();
      
      // Add logic here to clean up HTML (remove sections, add SVGs back)
      // Then redirect to sessions page
      navigate('/sessions');
    } catch (error) {
      console.error('Error saving and leaving:', error);
    }
  };

  const getTimeAgo = (timestamp) => {
    if (!timestamp) return 'Never';
    
    const minutes = Math.floor((Date.now() - timestamp) / 60000);
    if (minutes < 60) return `${minutes}m`;
    if (minutes < 1440) return `${Math.floor(minutes/60)}hr${minutes%60}m`;
    return `${Math.floor(minutes/1440)}d`;
  };

  return (
    <footer className="session-footer">
      <div className="footer-section">
        <span className="session-name">Session: {sessionId}</span>
      </div>
      <div className="footer-section">
        <span className="last-saved">Last saved: {getTimeAgo(lastSaved)}</span>
      </div>
      <div className="footer-section">
        <button className="save-button" onClick={onSave}>Save</button>
        <button className="save-leave-button" onClick={handleSaveAndLeave}>
          Save, Build & Leave
        </button>
      </div>
    </footer>
  );
}

export default SessionFooter;

