const OPENROUTER_API_URL = 'https://openrouter.ai/api/v1/chat/completions';
const OPENROUTER_API_KEY = process.env.REACT_APP_OPENROUTER_API_KEY;

export const editHTMLWithAI = async (selectedHTML, transcribedInstructions) => {
  try {
    if (!OPENROUTER_API_KEY) {
      throw new Error('OpenRouter API key is missing');
    }

    const promptText = `I need you to edit some HTML based on some instructions.

You are only editing a section of the HTML, so do not add any extra tags like <html>.

The code you are edit should begin with <section>...

The edited code you return should also begin with <section>...

Do not say "here is the code.." or anything like that.

Do not write \`\`\`html. Just return the edited code, beginning <section>

The instructions you have been given have been transcribed from a voice note, so may be somewhat rambling or vague.

But hopefully you can understand the changes that are required and edit them accordingly.

Please now return the code based on the instructions.

HTML CODE TO EDIT:

========================
${selectedHTML}
========================

Here are the instructions to follow:

========================
Please edit the HTML above based on these instructions. Do not add \`\`\`html or any comments. Do not replace any image or videos. Do not add extra tags or try to complete the HTML. Simply return the edited code based on the following instructions:

${transcribedInstructions}
========================

Now return the edited HTML`;

    const requestBody = {
      model: 'openai/gpt-4-turbo-preview',
      messages: [
        {
          role: 'user',
          content: promptText
        }
      ]
    };

    const response = await fetch(OPENROUTER_API_URL, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        Authorization: `Bearer ${OPENROUTER_API_KEY}`
      },
      body: JSON.stringify(requestBody)
    });

    if (!response.ok) {
      throw new Error(`OpenRouter request failed with status ${response.status}`);
    }

    const data = await response.json();
    console.log('OpenRouter raw response:', data);

    if (!data.choices?.[0]?.message?.content) {
      throw new Error('Unexpected structure in OpenRouter response');
    }

    return data.choices[0].message.content.trim();
  } catch (error) {
    console.error('OpenRouter API error:', error);
    throw error;
  }
};
